==> owncloud-app-calendar-1%3A1.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/fr.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Agenda",
    "Individual" : "Individuel",
    "Group" : "Groupe",
    "Resource" : "Ressource",
    "Room" : "Lieu",
    "Unknown" : "Inconnu",
    "Required" : "Requis",
    "Optional" : "Optionnel",
    "Does not attend" : "Ne participera pas",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Vous êtes dans un fuseau horaire inconnu ({tz}), retour à UTC",
    "New event" : "Nouvel événement",
    "Attendees" : "Participants",
    "Reminders" : "Rappels",
    "Repeating" : "Occurrences",
    "When shared show full event" : "Afficher l'événement complet en cas de partage",
    "When shared show only busy" : "Afficher seulement la plage horaire occupée en cas de partage",
    "When shared hide this event" : "Masquer cet événement en cas de partage",
    "Please add a title!" : "Veuillez ajouter un titre !",
    "Please select a calendar!" : "Veuillez sélectionner un calendrier !",
    "Global" : "Global",
    "None" : "Aucun",
    "Every day" : "Chaque jour",
    "Every week" : "Chaque semaine",
    "Every month" : "Chaque mois",
    "Every year" : "Chaque année",
    "never" : "jamais",
    "after" : "Après ",
    "At time of event" : "À l'heure de l'événement",
    "5 minutes before" : "5 minutes avant",
    "10 minutes before" : "10 minutes avant",
    "15 minutes before" : "15 minutes avant",
    "30 minutes before" : "30 minutes avant",
    "1 hour before" : "1 heure avant",
    "2 hours before" : "2 heures avant",
    "Custom" : "Personnalisé",
    "Audio" : "Son",
    "E Mail" : "Courriel",
    "Pop up" : "Fenêtre d'alerte",
    "sec" : "sec",
    "min" : "min",
    "hours" : "heures",
    "days" : "jours",
    "week" : "semaine",
    "before" : "avant",
    "Editing reminders of uknown type not supported." : "L'édition de rappels de type inconnu n'est pas supportée.",
    "Week {number} of {year}" : "Semaine {number} de {year}",
    "Successfully imported" : "Importé avec succès",
    "Partially imported, 1 failure" : "Partiellement importé, 1 échec",
    "Partially imported, {n} failures" : "Partiellement importé, {n} échecs",
    "Audio alarm" : "Alerte audio",
    "Pop-up" : "Fenêtre d'alerte",
    "E-Mail" : "Courriel",
    "{type} {time} before the event starts" : "{type} {time} avant l'événement",
    "{type} {time} before the event ends" : "{type} {time} avant la fin de l'événement",
    "{type} {time} after the event starts" : "{type} {time} après le début de l'événement",
    "{type} {time} after the event ends" : "{type} {time} après la fin de l'événement",
    "{type} at the event's start" : "{type} au début de l'événement",
    "{type} at the event's end" : "{type} à la fin de l'événement",
    "{type} at {time}" : "{type} à {time}",
    "{calendar} shared by {owner}" : "{calendar} partagé par {owner}",
    "Title of the Event" : "Titre de l'événement",
    "starts" : "démarre",
    "ends" : "termine",
    "All day Event" : "Journée entière",
    "Location" : "Emplacement",
    "Delete" : "Supprimer",
    "Cancel" : "Annuler",
    "More ..." : "Plus…",
    "Create" : "Créer",
    "Update" : "Mettre à jour",
    "Close" : "Fermer",
    "Description" : "Description",
    "Export" : "Exporter",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Veuillez contacter votre administrateur afin de lui demander de désactiver l'option de configuration \"asset-pipeline.enabled\".",
    "Day" : "Jour",
    "Week" : "Semaine",
    "Month" : "Mois",
    "Today" : "Aujourd'hui",
    "Share Calendar" : "Partager l'agenda",
    "More" : "Plus",
    "Edit" : "Éditer",
    "CalDAV" : "CalDAV",
    "group" : "groupe",
    "New Calendar" : "Nouvel agenda",
    "Subscriptions" : "Abonnements",
    "New Subscription" : "Nouvel abonnement",
    "Url" : "URL",
    "Edit event" : "Modifier l'événement",
    "Delete Event" : "Supprimer l'événement",
    "Save Event" : "Enregistrer l'événement",
    "Time" : "Heure",
    "Type" : "Type",
    "Relative" : "Relatif",
    "Absolute" : "Absolu",
    "Repeat" : "Répéter",
    "times every" : "Répéter tous les",
    "Add" : "Ajouter",
    "E-Mail address of attendee" : "Adresse courriel du participant",
    "Please add your email address in the personal settings in order to add attendees." : "Veuillez ajouter votre adresse mail dans les paramètres du comptes  dans l'ordre pour ajouter des participants .",
    "from" : "du",
    "to" : "à",
    "This event's repeating rule is not supported yet." : "La répétition de cet évènement n'est pas prise en charge pour le moment.",
    "Support for advanced rules will be added with subsequent updates." : "Le support de règles multiples sera ajouté dans des mises à jour ultérieures.",
    "Reset repeating rule" : "Réinitialiser la règle de répétition",
    "Repeat every ..." : "Répéter tous les ...",
    "end repeat ..." : "Arrêter la répétition ...",
    "times" : "fois",
    "Import Calendars" : "Importer des agendas",
    "Import canceled" : "Importation annulée",
    "Analyzing calendar" : "Analyse de l'agenda en cours",
    "The file contains objects incompatible with the selected calendar" : "Le fichier contient des objets incompatibles avec l'agenda sélectionné",
    "New calendar" : "Nouvel agenda",
    "Import scheduled" : "Importation planifiée",
    "Settings" : "Paramètres",
    "Import calendar" : "Importer un agenda",
    "No Calendars selected for import" : "Aucun agenda sélectionné pour import",
    "Primary CalDAV address" : "Adresse CalDAV principale",
    "iOS/OS X CalDAV address" : "Adresse CalDAV pour iOS/OS X"
},
"nplurals=2; plural=(n > 1);");

==> owncloud-app-calendar-1%3A1.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/fr.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Agenda",
    "Individual" : "Individuel",
    "Group" : "Groupe",
    "Resource" : "Ressource",
    "Room" : "Lieu",
    "Unknown" : "Inconnu",
    "Required" : "Requis",
    "Optional" : "Optionnel",
    "Does not attend" : "Ne participera pas",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Vous êtes dans un fuseau horaire inconnu ({tz}), retour à UTC",
    "Please create a calendar first." : "Veuillez d'abord créer un calendrier.",
    "New event" : "Nouvel événement",
    "Attendees" : "Participants",
    "Reminders" : "Rappels",
    "Repeating" : "Occurrences",
    "When shared show full event" : "Afficher l'événement complet en cas de partage",
    "When shared show only busy" : "Afficher seulement la plage horaire occupée en cas de partage",
    "When shared hide this event" : "Masquer cet événement en cas de partage",
    "Please add a title!" : "Veuillez ajouter un titre !",
    "Please select a calendar!" : "Veuillez sélectionner un calendrier !",
    "Global" : "Global",
    "None" : "Aucun",
    "Every day" : "Chaque jour",
    "Every week" : "Chaque semaine",
    "Every month" : "Chaque mois",
    "Every year" : "Chaque année",
    "never" : "jamais",
    "after" : "Après ",
    "At time of event" : "À l'heure de l'événement",
    "5 minutes before" : "5 minutes avant",
    "10 minutes before" : "10 minutes avant",
    "15 minutes before" : "15 minutes avant",
    "30 minutes before" : "30 minutes avant",
    "1 hour before" : "1 heure avant",
    "2 hours before" : "2 heures avant",
    "Custom" : "Personnalisé",
    "Audio" : "Son",
    "E Mail" : "Courriel",
    "Pop up" : "Fenêtre d'alerte",
    "sec" : "sec",
    "min" : "min",
    "hours" : "heures",
    "days" : "jours",
    "week" : "semaine",
    "before" : "avant",
    "start" : "début",
    "end" : "fin",
    "Editing reminders of uknown type not supported." : "L'édition de rappels de type inconnu n'est pas supportée.",
    "Week {number} of {year}" : "Semaine {number} de {year}",
    "Successfully imported" : "Importé avec succès",
    "Partially imported, 1 failure" : "Partiellement importé, 1 échec",
    "Partially imported, {n} failures" : "Partiellement importé, {n} échecs",
    "Audio alarm" : "Alerte audio",
    "Pop-up" : "Fenêtre d'alerte",
    "E-Mail" : "Courriel",
    "{type} {time} before the event starts" : "{type} {time} avant l'événement",
    "{type} {time} before the event ends" : "{type} {time} avant la fin de l'événement",
    "{type} {time} after the event starts" : "{type} {time} après le début de l'événement",
    "{type} {time} after the event ends" : "{type} {time} après la fin de l'événement",
    "{type} at the event's start" : "{type} au début de l'événement",
    "{type} at the event's end" : "{type} à la fin de l'événement",
    "{type} at {time}" : "{type} à {time}",
    "{calendar} shared by {owner}" : "{calendar} partagé par {owner}",
    "Title of the Event" : "Titre de l'événement",
    "starts" : "démarre",
    "ends" : "termine",
    "All day Event" : "Journée entière",
    "Location" : "Emplacement",
    "Delete" : "Supprimer",
    "Cancel" : "Annuler",
    "More ..." : "Plus…",
    "Create" : "Créer",
    "Update" : "Mettre à jour",
    "Close" : "Fermer",
    "Description" : "Description",
    "Export" : "Exporter",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "A cause d'un bug en amont, le calendrier ne peut actuellement pas prendre en charge la fonction de pipeline d'actifs.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Veuillez contacter votre administrateur afin de lui demander de désactiver l'option de configuration \"asset-pipeline.enabled\".",
    "Day" : "Jour",
    "Week" : "Semaine",
    "Month" : "Mois",
    "Today" : "Aujourd'hui",
    "Share Calendar" : "Partager l'agenda",
    "More" : "Plus",
    "Edit" : "Éditer",
    "CalDAV" : "CalDAV",
    "group" : "groupe",
    "New Calendar" : "Nouvel agenda",
    "Subscriptions" : "Abonnements",
    "New Subscription" : "Nouvel abonnement",
    "Url" : "URL",
    "Edit event" : "Modifier l'événement",
    "Delete Event" : "Supprimer l'événement",
    "Save Event" : "Enregistrer l'événement",
    "Time" : "Heure",
    "Type" : "Type",
    "Relative" : "Relatif",
    "Absolute" : "Absolu",
    "Repeat" : "Répéter",
    "times every" : "Répéter tous les",
    "Add" : "Ajouter",
    "E-Mail address of attendee" : "Adresse courriel du participant",
    "Please add your email address in the personal settings in order to add attendees." : "Veuillez ajouter votre adresse mail dans les paramètres du comptes  dans l'ordre pour ajouter des participants .",
    "from" : "du",
    "to" : "à",
    "This event's repeating rule is not supported yet." : "La répétition de cet évènement n'est pas prise en charge pour le moment.",
    "Support for advanced rules will be added with subsequent updates." : "Le support de règles multiples sera ajouté dans des mises à jour ultérieures.",
    "Reset repeating rule" : "Réinitialiser la règle de répétition",
    "Repeat every ..." : "Répéter tous les ...",
    "end repeat ..." : "Arrêter la répétition ...",
    "times" : "fois",
    "Import Calendars" : "Importer des agendas",
    "Import canceled" : "Importation annulée",
    "Analyzing calendar" : "Analyse de l'agenda en cours",
    "The file contains objects incompatible with the selected calendar" : "Le fichier contient des objets incompatibles avec l'agenda sélectionné",
    "New calendar" : "Nouvel agenda",
    "Import scheduled" : "Importation planifiée",
    "Settings" : "Paramètres",
    "Import calendar" : "Importer un agenda",
    "No Calendars selected for import" : "Aucun agenda sélectionné pour import",
    "Primary CalDAV address" : "Adresse CalDAV principale",
    "iOS/OS X CalDAV address" : "Adresse CalDAV pour iOS/OS X"
},
"nplurals=2; plural=(n > 1);");
